@@ -9,14 +9,8 @@ use Readonly;
 
 CloudApp::REST::Item - Base class for all items
 
-=head1 VERSION
-
-Version 0.01
-
 =cut
 
-our $VERSION = '0.01';
-
 use MooseX::Types::DateTimeX qw(DateTime);
 use MooseX::Types::URI qw(Uri);
 
@@ -29,7 +23,7 @@ has id           => (is => 'ro', required => 1, isa     => 'Int',);
 has owner_id     => (is => 'ro', required => 1, isa     => 'Int',);
 
 has item_type    => (is => 'ro', required => 1, isa => 'Str',);
-has name         => (is => 'ro', required => 1, isa => 'Str',);
+has name         => (is => 'ro', required => 0, isa => 'Str',);
 has private_slug => (is => 'ro', required => 0, isa => 'Str',);
 has public_slug  => (is => 'ro', required => 0, isa => 'Str',);
 
@@ -94,19 +88,19 @@ sub slug {
 
 =head2 content_url
 
-This is the L<URL|Uri> of the content, eg. the file itself.
+This is the L<URL|URI> of the content, eg. the file itself.
 
 =head2 icon
 
-The L<URL|Uri> to the item icon at CloudApp.
+The L<URL|URI> to the item icon at CloudApp.
 
 =head2 href
 
-The private L<URL|Uri> to the item at CloudApp.
+The private L<URL|URI> to the item at CloudApp.
 
 =head2 url
 
-The public short L<URL|Uri> to the item at CloudApp.
+The public short L<URL|URI> to the item at CloudApp.
 
 =head2 created_at
 
@@ -124,13 +118,13 @@ The date when this item was deleted at CloudApp.  If set, returns a L<DateTime>
 
 Following methods are inherited by every C<CloudApp::REST::Item::*> module:
 
-=head2 delete( )
+=head2 delete
 
 Deletes the current item at CloudApp.  The item instance can be used after deleting
 as long as the instance won't go out of scope, but won't be updated automatically.
 CloudApp moves this item to the trash after detelion.
 
-Dies if the item is L<stripped|strip___>.
+Dies if the item is L</strip>ed.
 
 =cut
 
@@ -142,7 +136,7 @@ sub delete {
     $self->_REST->_delete_item($self);
 }
 
-=head2 strip( )
+=head2 strip
 
 Removes the reference to L<CloudApp::REST>.
 
