@@ -7,15 +7,9 @@ use MooseX::Types::URI qw(Uri);
 
 CloudApp::REST::Item::Boomark - Boomark item class of CloudApp::REST
 
-=head1 VERSION
-
-Version 0.01
-
 =cut
 
-our $VERSION = '0.01';
-
-has item_type => (is => 'ro', required => 1, isa => 'Str', default => 'boomark',);
+has item_type => (is => 'ro', required => 1, isa => 'Str', default => 'bookmark',);
 has redirect_url => (is => 'ro', required => 0, isa => Uri, coerce => 1);
 
 with 'CloudApp::REST::Item';
@@ -31,7 +25,7 @@ The attributes listed here are only accessible for bookmark items.
 
 =head2 redirect_url
 
-The L<URL|Uri> this bookmark links to.
+The L<URL|URI> this bookmark links to.
 
 =head1 SEE ALSO
 
