@@ -7,14 +7,8 @@ use MooseX::Types::URI qw(Uri);
 
 CloudApp::REST::Item::Unknown - Unknown item class of CloudApp::REST
 
-=head1 VERSION
-
-Version 0.01
-
 =cut
 
-our $VERSION = '0.01';
-
 has item_type => (is => 'ro', required => 1, isa => 'Str', default => 'unknown',);
 has remote_url => (is => 'ro', required => 0, isa => Uri, coerce => 1);
 
@@ -31,7 +25,7 @@ The attributes listed here are only accessible for C<Unknown> items.
 
 =head2 remote_url
 
-This seems to be the same as the L<CloudApp::REST::Item/content_url>.  Returns an L<URL|Uri> instance.
+This seems to be the same as the L<CloudApp::REST::Item/content_url>.  Returns an L<URL|URI> instance.
 
 Although most of the items has a remote_url, this attribute is item specific.
 
